package com.baicizhan.base

import android.os.Handler
import android.support.v7.app.AppCompatActivity
import com.baicizhan.client.business.widget.BczLoadingDialog
import com.baicizhan.client.framework.log.L

/**
 * Created by Jacee.
 * Date: 2020.06.29
 */
open class LoadingDialogActivity : AppCompatActivity() {

    private val loadingDialog by lazy {
        BczLoadingDialog(this).apply {
            setCancelable(false)
        }
    }
    private val handler = Handler()
    private var isLoadingDialogShowing = false
    private var delayedLoading: DelayedLoading? = null

    private inner class DelayedLoading : Runnable {
        override fun run() {
            L.d(TAG, "delayed showing")
            loadingDialog.show()
            isLoadingDialogShowing = true
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        handler.removeCallbacksAndMessages(null)
        if (isLoadingDialogShowing) {
            loadingDialog.dismiss()
        }
    }

    private fun removePending() {
        delayedLoading?.let {
            handler.removeCallbacks(it)
        }
        delayedLoading = null;
    }

    @JvmOverloads
    protected fun setLoading(isLoading: Boolean, delay: Long = 0) {
        L.d(TAG, "isLoading = $isLoading, showing = $isLoadingDialogShowing, delay = $delay")
        if (isLoading && isLoadingDialogShowing) {
            return
        }

        removePending()
        if (isLoading) {
            if (delay > 0) {
                handler.postDelayed(DelayedLoading().also { delayedLoading = it }, delay)
            } else {
                loadingDialog.show()
                isLoadingDialogShowing = true
            }
        } else {
            loadingDialog.dismiss()
            isLoadingDialogShowing = false
        }
    }

    companion object {
        private val TAG = LoadingDialogActivity::class.java.simpleName
    }
}