package com.baicizhan.client.business.view

import android.os.SystemClock
import android.util.Log
import android.view.View
import android.widget.TextView
import com.baicizhan.client.business.BuildConfig
import com.baicizhan.client.business.view.OnProtectedClickListener.PROTECTED_DELAY

/**
 * Created by Jacee.
 * Date: 2020.04.07
 */

private const val TAG = "view_ext"

fun View.setOnProtectedClickListener(l: (View) -> Unit) {
    var time: Long = 0
    setOnClickListener {
        val cur = SystemClock.elapsedRealtime()
        if (BuildConfig.DEBUG) Log.d(TAG, "time = $time, cur = $cur, ${time + PROTECTED_DELAY < cur}")
        if (time == 0L || time + PROTECTED_DELAY < cur) {
            l(it)
            time = cur
        }
    }
}

fun View.setOnProtectedClickListener(l: View.OnClickListener) {
    var time: Long = 0
    setOnClickListener {
        val cur = SystemClock.elapsedRealtime()
        if (BuildConfig.DEBUG) Log.d(TAG, "time = $time, cur = $cur, ${time + PROTECTED_DELAY < cur}")
        if (time == 0L || time + PROTECTED_DELAY < cur) {
            l.onClick(it)
            time = cur
        }
    }
}

fun Array<View>.setOnProtectedClickListener(l: (View) -> Unit) {
    forEach {
        it.setOnProtectedClickListener { v -> l(v) }
    }
}

var View.visible: Boolean
    get() = visibility == View.VISIBLE
    set(value) {
        visibility = if (value) View.VISIBLE else View.GONE
    }

var TextView.content: CharSequence?
    get() = text
    set(value) {
        text = value
        visible = !value.isNullOrEmpty()
    }